==> vue-select-3.0.0.tgz: package/docs/README.md <==
# Vue Select

![Current Release](https://img.shields.io/github/release/sagalbot/vue-select.svg?style=flat-square)
![Bundle Size](https://img.shields.io/bundlephobia/min/vue-select.svg?style=flat-square) 
![Monthly Downloads](https://img.shields.io/npm/dm/vue-select.svg?style=flat-square) 
![Code Coverage](https://img.shields.io/coveralls/github/sagalbot/vue-select.svg?style=flat-square) 
![Maintainability Score](https://img.shields.io/codeclimate/maintainability/sagalbot/vue-select.svg?style=flat-square) 
![MIT License](https://img.shields.io/github/license/sagalbot/vue-select.svg?style=flat-square) 

> Everything you wish the HTML `<select>` element could do, wrapped 
up into a zero dependency, highly extensible Vue component. 

Vue Select is a feature rich select/dropdown/typeahead component. It provides a default
template that fits the 80% use case for a select dropdown. Here it is by default:

<div style="max-width:25rem; margin: 0 auto; padding: 1rem 0;">
  <country-select />  
</div>

If you want to get a quick sense of what vue-select can do, check out
[the sandbox](sandbox.md). 

#### Features
- Tagging
- Filtering/Searching
- Vuex Support
- AJAX Support
- SSR Support
- Select Single/Multiple Options
- Tested with Bootstrap 3/4, Bulma, Foundation
- +95% Test Coverage
- ~20kb Total / ~5kb CSS / ~15kb JS
- Zero dependencies

#### Resources
- **[CodePen Template](http://codepen.io/sagalbot/pen/NpwrQO)**
- **[GitHub](https://github.com/sagalbot/vue-select)**
- **[Projects](https://github.com/sagalbot/vue-select/projects)**

==> vue-select-3.2.0.tgz: package/docs/README.md <==
# Vue Select

![Current Release](https://img.shields.io/github/release/sagalbot/vue-select.svg?style=flat-square)
![Bundle Size](https://flat.badgen.net/bundlephobia/min/vue-select) 
![Monthly Downloads](https://img.shields.io/npm/dm/vue-select.svg?style=flat-square) 
![Code Coverage](https://img.shields.io/coveralls/github/sagalbot/vue-select.svg?style=flat-square) 
![Maintainability Score](https://img.shields.io/codeclimate/maintainability/sagalbot/vue-select.svg?style=flat-square) 
![MIT License](https://img.shields.io/github/license/sagalbot/vue-select.svg?style=flat-square) 

> Everything you wish the HTML `<select>` element could do, wrapped 
up into a lightweight, extensible Vue component. 

Vue Select is a feature rich select/dropdown/typeahead component. It provides a default
template that fits the 80% use case for a select dropdown. Here it is by default:

<div style="max-width:25rem; margin: 0 auto; padding: 1rem 0;">
  <country-select />  
</div>

If you want to get a quick sense of what vue-select can do, check out
[the sandbox](sandbox.md). 

#### Features
- Tagging
- Filtering/Searching
- Vuex Support
- AJAX Support
- SSR Support
- Select Single/Multiple Options
- Tested with Bootstrap 3/4, Bulma, Foundation
- +95% Test Coverage
- ~20kb Total / ~5kb CSS / ~15kb JS
- Zero dependencies

#### Resources
- **[CodePen Template](http://codepen.io/sagalbot/pen/NpwrQO)**
- **[GitHub](https://github.com/sagalbot/vue-select)**
- **[Projects](https://github.com/sagalbot/vue-select/projects)**
